==> nhl97-ts_utils-1.6.3.tgz: package/src/array_utils.ts <==
export function from_1_to_n(n: number): number[] {
  return Array.from({ length: n }, (v: any, i) => i + 1)
}

export function from_0_to_n(n: number): number[] {
  return Array.from({ length: n + 1 }, (v: any, i) => i)
}

export function from_n_to_m(n: number, m: number): number[] {
  return Array.from({ length: m - n }, (v: any, i) => i + n)
}

export function zipWith<A, B, C>(fn: (a: A, b: B) => C, arr1: A[], arr2: B[]): C[] {
  return arr1.map((v, i) => {
    return fn(v, arr2[i]);
  });
}

export function zip<A, B, C>(arr1: A[], arr2: B[]): [A, B][] {
  return arr1.map((v, i) => {
    return [v, arr2[i]];
  });
}

export function exclude<A>(arr: A[], exlusionCriteria: (elem: A) => boolean): A[] {
  return arr.filter((elem) => !exlusionCriteria(elem))
}

export function mutating_delete_at<T>(array: T[], index: number): T[] {
  array.splice(index, 1)
  return array
}


export function minimum_by<A>(array: A[], sortFn: (a: A, b: A) => number): A {
  if (array.length == 0) throw new Error("minimum_by applied to empty array")
  return array.sort(sortFn)[0]
}

export function maximum_by<A>(array: A[], sortFn: (a: A, b: A) => number): A {
  if (array.length == 0) throw new Error("maximum_by applied to empty array")
  return array.sort(sortFn)[array.length - 1]
}

export function toArrayLiteralString(array: readonly number[] | readonly string[]): string {
  if (array.length == 0) return "[]"
  if (typeof array[0] == "number") {
    return `[${array.join(", ")}]`
  } else {
    return `["${array.join('", "')}"]`
  }
}

==> nhl97-ts_utils-1.6.5.tgz: package/src/array_utils.ts <==
import {Fn} from "./TypeUtils";

export function from_1_to_n(n: number): number[] {
  return Array.from({length: n}, (v: any, i) => i + 1)
}

export function from_0_to_n(n: number): number[] {
  return Array.from({length: n + 1}, (v: any, i) => i)
}

export function from_n_to_m(n: number, m: number): number[] {
  return Array.from({length: m - n}, (v: any, i) => i + n)
}

export function zipWith<A, B, C>(fn: (a: A, b: B) => C, arr1: A[], arr2: B[]): C[] {
  return arr1.map((v, i) => {
    return fn(v, arr2[i]);
  });
}

export function zip<A, B, C>(arr1: A[], arr2: B[]): [A, B][] {
  return arr1.map((v, i) => {
    return [v, arr2[i]];
  });
}

export function exclude<A>(arr: A[], exlusionCriteria: (elem: A) => boolean): A[] {
  return arr.filter((elem) => !exlusionCriteria(elem))
}

export function mutating_delete_at<T>(array: T[], index: number): T[] {
  array.splice(index, 1)
  return array
}


export function minimum_by<A>(array: A[], sortFn: (a: A, b: A) => number): A {
  if (array.length == 0) throw new Error("minimum_by applied to empty array")
  return array.sort(sortFn)[0]
}

export function maximum_by<A>(array: A[], sortFn: (a: A, b: A) => number): A {
  if (array.length == 0) throw new Error("maximum_by applied to empty array")
  return array.sort(sortFn)[array.length - 1]
}

export function toArrayLiteralString(array: readonly number[] | readonly string[]): string {
  if (array.length == 0) return "[]"
  if (typeof array[0] == "number") {
    return `[${array.join(", ")}]`
  } else {
    return `["${array.join('", "')}"]`
  }
}

/**
 *
 * @param type_guard
 */
export function filter_and_assert_type<ElemT, AssertedT extends ElemT>
(type_guard: ((el: ElemT) => el is AssertedT)): Fn<ElemT[], AssertedT[]> {
  return (elems) => (
    elems
      .filter((elem) => type_guard(elem))
      .map((elem) => {
          if (type_guard(elem))
            return elem
          else
            throw new Error("BUG in (usage of?) filter_and_assert_type.")
        }
      )
  )

}
